#
# spec file for package xinit
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           xinit
Version:        1.3.4
Release:        4.3
Summary:        X Window System initializer
License:        MIT
Group:          System/X11/Utilities
Url:            http://xorg.freedesktop.org/
Source0:        http://xorg.freedesktop.org/releases/individual/app/%{name}-%{version}.tar.bz2
Source1:        xinit.tar.bz2
Source2:        keygen.c
Source3:        keygen.1
Patch0:         xinit.diff
Patch1:         xinit-client-session.patch
Patch2:         xinit-suse.patch
Patch3:         xinit-tolerant-hostname-changes.patch
# needed for patch0
BuildRequires:  gcc-c++
BuildRequires:  libtool
BuildRequires:  pkg-config
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xorg-macros) >= 1.8
BuildRequires:  pkgconfig(xproto) >= 7.0.17
Requires:       setxkbmap
Requires:       xauth
Requires:       xmodmap
Requires:       xrdb
Requires:       xsetroot
%if 0%{?suse_version} > 1320
Requires:       xterm-bin
%else
Requires:       xterm
%endif
# This was part of the xorg-x11 package up to version 7.6
Conflicts:      xorg-x11 <= 7.6
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
The xinit program is used to start the X Window System server and a
first client program on systems that are not using a display manager
such as xdm or in environments that use multiple window systems.
When this first client exits, xinit will kill the X server and then
terminate.

%prep
%setup -q
%patch0 -p0
%patch1 -p1
%patch2 -p1
%patch3 -p1
# needed for patch0
autoreconf -fi

%build
%configure
make %{?_smp_mflags}
%{__cc} %{optflags} -o keygen %{SOURCE2}

%install
%make_install
install -m 0644 %{SOURCE3} %{buildroot}%{_mandir}/man1
install -m 0711 keygen %{buildroot}%{_bindir}/keygen
pushd %{buildroot}
tar xf %{SOURCE1}
popd
install -D %{buildroot}%{_sysconfdir}/X11/xinit/xinitrc %{buildroot}%{_sysconfdir}/skel/.xinitrc.template

%files
%defattr(-,root,root)
%doc ChangeLog COPYING README
%config %{_sysconfdir}/X11/xinit/
%config %{_sysconfdir}/X11/Xresources
%config %{_sysconfdir}/skel/.xinitrc.template
%{_bindir}/keygen
%{_bindir}/startx
%{_bindir}/xinit
%{_mandir}/man1/keygen.1%{?ext_man}
%{_mandir}/man1/startx.1%{?ext_man}
%{_mandir}/man1/xinit.1%{?ext_man}

%changelog
* Sun May 10 2015 Led <ledest@gmail.com>
- fix bashism in startx script
- update patches:
  * xinit-suse.patch
* Wed Mar 18 2015 sndirsch@suse.com
- fixed bugnumer reference in previous changelog entry
* Wed Mar 11 2015 werner@suse.de
- Allow WINDOWMANAGER to be a command line string (bsc#921172)
* Wed Jan 28 2015 sndirsch@suse.com
- startx.cpp:
  * /usr/X11R6/bin/X --> /usr/bin/X
  * /var/X11R6/bin/X --> /var/lib/X11/X
- refreshed patches
* Fri Jan 23 2015 sndirsch@suse.com
- apparently with release 1.3.4 xinit needs cc1plus; otherwise
  generation of startx fails and results in a file with a size
  of 0 bytes
* Wed Jan 21 2015 sndirsch@suse.com
- Fixed some more spacing and minor issues in adapted patches
* Tue Jan 20 2015 sfalken@opensuse.org
- Fixed some spacing and single quote vs backtick issues
  in patches
* Mon Jan 19 2015 sfalken@opensuse.org
- Corrections to variable names in xinit-suse.patch and
  xinit-tolerant-hostname-changes.patch
* Sun Jan 18 2015 sfalken@opensuse.org
- Update to version 1.3.4:
  + Changes from 1.3.3
  - Fix warnings about parameters to startServer & startClient
    shadowing globals
  - Pass files to cpp via CLI arg instead of stdin to workaround
    gcc 4.8 change (fdo#69439)
  - Remove unixware / sco support
  - Bump required util-macros version to 1.19
  - Replace $RAWCPPFLAGS with $TRADITIONALCPPFLAGS when processing
    cpp files
  - Under Linux start X on the current VT (rh#806491)
  - startx; Pass vtX as long as the user did not specify one
  - configure: Drop AM_MAINTAINER_MODE
  - autogen.sh: Honor NOCONFIGURE=1
  - startx: Make the bugzilla reference in a comment survive cpp
    processing (fdo#83019)
  - Remove hardcoded path to OpenSSL for OpenBSD
  + Patches refactored/renamed for version change
  + Added:
  - xinit-client-session.patch
  - xinit-tolerant-hostname-changes.patch
  - xinit-suse.patch
  - xinit-1.3.4.tar.bz2
  + Modified:
  - xinit-client-session.patch
  + Dropped:
  - xinit-tolerant-hostname-changes.diff
  - xinit-suse.diff
  - xinit-1.3.3.tar.bz2
* Wed Dec 17 2014 dimstar@opensuse.org
- On openSUSE > 13.2, xterm has been split into xterm-bin for the
  program and xterm for the app launcher. We only need the program,
  so conditionall Require xterm-bin.
* Tue Sep  9 2014 sndirsch@suse.com
- add info to run chkstat after modifying /etc/permissions.local
  in order to run startx (bnc#895647)
* Wed Jan  8 2014 lnussel@suse.de
- don't call the obsolete wmlist. Read /usr/share/xsessions instead.
* Mon Sep 16 2013 sndirsch@suse.com
- fixed loading of .xkb files (bnc#840408)
* Thu Sep 12 2013 zaitor@opensuse.org
- Update to version 1.3.3:
  + Add Apple copyright/license notice from launchd files to
    COPYING.
  + Use pid_t instead of int for type of pids.
  + Check for openssl as mkcookie fallback on all platforms, not
    just OpenBSD.
  + Declare processTimeout() as taking a const string arg.
  + If we have to forcibly kill the Xserver on Solaris, reset
    kbd_mode.
  + Add printf attributes suggested by gcc.
  + install: Use sysconfdir instead of libdir for config files.
  + man: Set correct config file location in man page.
  + privileged_startx: use root:wheel instead of 0:0.
  + XQuartz: Fix an issue where -dpi was not being passed to the
    server despite being set.
  + Annotate Fatal and Fatalx as _X_NORETURN.
  + darwin: Silence a syslog message from defaults.
  + laucnhd:
  - Silence some syslog spam.
  - Fix the destination of moved-aside directories in
    privileged_startx.
  - Load privileged_startx properly on Tiger.
  - Provide more verbose error reporting for launchd checkin
    failures.
  - Don't provide the LaunchAgent on Tiger.
  + launchd/privileged_startx: Improved error resolution.
- Add pkgconfig(xproto) BuildRequires, new dependency.
* Wed Dec  5 2012 werner@suse.de
- Move xinitrc.d sourcing part to xinit.common to make it work
  even with xdm session scripts
- Detect other running X server in xserverrc
* Mon Jul  2 2012 werner@suse.de
- Allow xinitrc scripts to be sourced (bnc#750980)
* Sun Apr 15 2012 vuntz@opensuse.org
- Move /etc/X11/Xresources from xorg-x11 to this package (in
  xinit.tar.bz2), since this is the base package using this file.
* Sat Apr 14 2012 dimstar@opensuse.org
- Update to version 1.3.2:
  + Use default clientargs, serverargs, and display if none were
    set
  + launchd: Add an option (--with-launchagent-xserver) to set the
    default X11 server
  + startx: Choose an unused $DISPLAY by default on all platforms
    (fdo#1789)
  + Include <sys/time.h> and <sys/resource.h> unconditionally
    (fdo#40632)
  + darwin: Buildfix for Tiger which doesn't have posix_spawn
- Changes from version 1.3.1:
  + launchd: Brownbag fix string compare
  + launchd: console_redirect: Actually read and log the remaining
    data when we get EV_EOF
  + launchd: Enable stdout/stderr redirection to ASL
  + launchd: Fix an array-index-out-of-bounds crasher
  + launchd: Log messages to ASL rather than fprintf
  + launchd: Reorganized layout of launchd sources
  + launchd: Set the correct id for privileged_startx
  + launchd: Silence clang static analyzer
  + launchd: syslog: Use facility org.x rather than user
  + launchd: Update console redirection to work with libdispatch
  + privileged_startx: Prefer /usr/bin/mktemp
  + Rename launchd-id-prefix to bundle-id-prefix
  + Use XORG_MANPAGE_SECTIONS rather than cpprules.in to build man
    pages
  + Build system fixes.
- Rebase xinit.diff.
* Fri Apr 13 2012 vuntz@opensuse.org
- Split xinit from xorg-x11. Initial version: 1.3.0.
